#!/usr/bin/env python
"""Script to help fix the temperature range displayed by a VDO cluster."""

import glob
import os
import struct
import sys

# Determine how to display the graph
if os.name == 'nt':
	open_cmd = 'start'
elif os.name == 'posix':
	# Sorry linux/bsd users :(
	open_cmd = 'open'

# Figure out the filename
files = []
for file in glob.glob('*.eep'):
	files.append(file)
files.sort()
for index in range(len(files)):
	print '%d: %s' % (index+1, files[index])
while True:
	file_number = raw_input('\nSelect a file: ')
	try:
		filename = files[int(file_number)-1]
		break
	except ValueError:
		print 'Invalid selection!'
	except IndexError:
		print 'Invalid selection!'

# Read in the cluster dump
source_file = open(filename, 'r').read()
temperature_scale_x = source_file[724:736]
temperature_scale_y = source_file[736:748]
#print 'x: %d bytes: %s' % (len(temperature_scale_x), repr(temperature_scale_x))
#print 'y: %d bytes: %s' % (len(temperature_scale_y), repr(temperature_scale_y))

# Extract the temperature values
data_format = '6h'
x = struct.unpack(data_format, temperature_scale_x)
y = struct.unpack(data_format, temperature_scale_y)

# Calculate the new Y values
if y[0] != y[1] or y[2] != y[3]:
	print 'Warning: Unexpected temp values, cluster has been modified!'
step = (y[4] - y[1]) / 3
z = (y[0], y[1], y[1]+step, y[1]+(step*2), y[4], y[5])

# Show the user the graph
gnuplot_file = open('graph.txt', 'w')
gnuplot_file.write('# x old_y new_y\n')
for index in range(6):
	gnuplot_file.write('%d %d %d\n' % (x[index], y[index], z[index]))
gnuplot_file.close()
os.system('gnuplot graph.gnuplot')
os.system('%s graph.png' % open_cmd)

# Make sure the user is happy
print 'X Values:         ', repr(x)
print 'Current Y Values: ', repr(y)
print 'New Y Values:     ', repr(z)
answer = raw_input('\nDoes this look OK? [y/N] ')
if answer.lower() != 'y':
	print 'Cluster dump not written!'
	sys.exit(1)

# Write the new cluster dump
new_y = struct.pack(data_format, z[0], z[1], z[2], z[3], z[4], z[5])
newfile = source_file[:736]+new_y+source_file[748:]
newfilename = filename[:-4] + ' - New.eep'
open(newfilename, 'w').write(newfile)
print 'Wrote new cluster dump to "%s"' % newfilename
